jactorch.nn.simple
==================

.. automodule:: jactorch.nn.simple

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      AutoResetParametersMixin
      Identity
      TorchApplyRecorderMixin
   
   

   
   
   

   
   
   








.. rubric:: Class AutoResetParametersMixin
.. autoclass:: AutoResetParametersMixin
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Identity
.. autoclass:: Identity
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class TorchApplyRecorderMixin
.. autoclass:: TorchApplyRecorderMixin
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







